===============================
UKMDB itop
===============================

.. image:: https://img.shields.io/pypi/v/ukmdb_itop.svg
        :target: https://pypi.python.org/pypi/ukmdb_itop

.. image:: https://img.shields.io/travis/mleist/ukmdb_itop.svg
        :target: https://travis-ci.org/mleist/ukmdb_itop

.. image:: https://readthedocs.org/projects/ukmdb_itop/badge/?version=latest
        :target: https://readthedocs.org/projects/ukmdb_itop/?badge=latest
        :alt: Documentation Status

.. image:: https://img.shields.io/pypi/l/ukmdb_itop.svg

.. image:: https://img.shields.io/pypi/pyversions/ukmdb_itop.svg

.. image:: https://img.shields.io/pypi/status/ukmdb_itop.svg

.. image:: https://img.shields.io/pypi/dm/ukmdb_itop.svg


UKMDB itop adapter.

* Free software: GPLv3 license
* Documentation: https://ukmdb_itop.readthedocs.org.

Features
--------

* TODO

Credits
---------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
